@@ -75,7 +75,7 @@ def get_all_index_dates_from_db(index: str, access_token: str, verbose: bool = T
 
 
 def get_index_dates_data_from_db(index: str, review_year: int, review_month: int, review_type: str,
-                                        access_token: str, verbose: bool = True):
+                                 access_token: str, verbose: bool = True):
     """
     This function enables the user to collect all date information held in the database relating to a specific
     index review. The function firstly checks that the arguments are of the correct type, followed by attempting to
@@ -122,3 +122,38 @@ def get_index_dates_data_from_db(index: str, review_year: int, review_month: int
             print("Status Code: {}, {}.".format(response.status_code, response.text))
         return pd.DataFrame()
 
+
+def get_all_dates_from_db(access_token: str, verbose: bool = True):
+    """
+    This function enables the user to collect all date information held in the database. The function firstly checks
+    that the arguments are of the correct type, followed by attempting to collect the requested information from the
+    database. If the information is available, it is returned as a Pandas DataFrame, otherwise, empty data shall be
+    returned, with an appropriate status code printed if verbose=True.
+
+    :param access_token: the access token of the user, must be an active access token. (str)
+    :param verbose: determines if status is printed. Default=True. (bool)
+    :return: dataset: a Pandas DataFrame containing all data relating to the index argument. (pd.DataFrame)
+    """
+    if not isinstance(access_token, str):
+        raise TypeError("The 'access_token' argument must be a string type.")
+    if not isinstance(verbose, bool):
+        raise TypeError("The 'verbose' argument must be a boolean type.")
+    url = "https://www.samsonrockapis.com/date_mapping"
+    header = {'Authorization': 'Bearer ' + access_token}
+    response = requests.get(url, headers=header)
+    if response.status_code == 200:
+        if verbose:
+            print("Status Code: {}".format(response.status_code))
+        return pd.read_json(response.text)
+    elif response.status_code == 404:
+        if verbose:
+            print("Status Code: {}, cannot find Date information.".format(response.status_code))
+        return pd.DataFrame()
+    elif response.status_code in [401, 403]:
+        if verbose:
+            print("Status Code: {}, user not properly authenticated for endpoint.".format(response.status_code))
+        return pd.DataFrame()
+    else:
+        if verbose:
+            print("Status Code: {}, {}.".format(response.status_code, response.text))
+        return pd.DataFrame()
