@@ -1,6 +1,7 @@
 import requests
 import pandas as pd
 import json
+import re
 
 
 def post_flows_to_database(dataset: pd.DataFrame, access_token: str, verbose: bool = True):
@@ -143,6 +144,9 @@ def get_index_review_data_single_day(index: str, review_year: int, review_month:
         raise TypeError("The 'review_year' and 'review_month' arguments must be integer types.")
     if not isinstance(verbose, bool):
         raise TypeError("The 'verbose' argument must be a boolean type.")
+    if not re.match("([12]\\d{3}-(0[1-9]|1[0-2])-(0[1-9]|[12]\\d|3[01]))", date):
+        raise ValueError("The 'date' argument must be passed in the format 'YYYY-MM-DD'.")
+
     url = "https://www.samsonrockapis.com/forecast_flows&index={}" \
           "&review_year={}&review_month={}&review_name={}&date={}".format(index, review_year, review_month,
                                                                           review_type, date)
@@ -194,6 +198,8 @@ def get_index_review_data_daterange(index: str, review_year: int, review_month:
         raise TypeError("The 'review_year' and 'review_month' arguments must be integer types.")
     if not isinstance(verbose, bool):
         raise TypeError("The 'verbose' argument must be a boolean type.")
+    if not all(re.match("([12]\\d{3}-(0[1-9]|1[0-2])-(0[1-9]|[12]\\d|3[01]))", v) for v in [start_date, end_date]):
+        raise ValueError("The 'start_date' and 'end_date' arguments must be passed in the format 'YYYY-MM-DD'.")
 
     url = "https://www.samsonrockapis.com/forecast_flows&index={}&review_year={}" \
           "&review_month={}&review_name={}&start_date={}&end_date={}".format(index, review_year, review_month,
